@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.10'; # TRIAL
+our $VERSION = '0.11'; # TRIAL
 
 use Package::Variant
   importing => ['Moo'],
@@ -92,7 +92,7 @@ Data::Record::Serialize - Flexible serialization of a record
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -406,6 +406,17 @@ Encode and send the record to the associated sink.
 B<WARNING>: the passed hash is modified.  If you need the original
 contents, pass in a copy.
 
+=head2 B<close>
+
+  $s->close;
+
+Flush any data written to the sink and close it.  While this will be
+performed automatically when the object is destroyed, if the object is
+not destroyed prior to global destruction at the end of the program,
+it is quite possible that it will not be possible to perform this
+cleanly.  In other words, make sure that sinks are closed prior to
+global destruction.
+
 =head2 B<output_fields>
 
   $array_ref = $s->fields;
@@ -839,6 +850,18 @@ __END__
 #pod B<WARNING>: the passed hash is modified.  If you need the original
 #pod contents, pass in a copy.
 #pod
+#pod
+#pod =head2 B<close>
+#pod
+#pod   $s->close;
+#pod
+#pod Flush any data written to the sink and close it.  While this will be
+#pod performed automatically when the object is destroyed, if the object is
+#pod not destroyed prior to global destruction at the end of the program,
+#pod it is quite possible that it will not be possible to perform this
+#pod cleanly.  In other words, make sure that sinks are closed prior to
+#pod global destruction.
+#pod
 #pod =head2 B<output_fields>
 #pod
 #pod   $array_ref = $s->fields;
