@@ -2,7 +2,7 @@ package Data::Record::Serialize::Role::Base;
 
 use Moo::Role;
 
-our $VERSION = '0.10'; # TRIAL
+our $VERSION = '0.11'; # TRIAL
 
 use Types::Standard qw[ ArrayRef HashRef Enum Str Bool is_HashRef ];
 
@@ -320,7 +320,7 @@ sub _set_types_from_record {
 
 sub DEMOLISH {
 
-    $_[0]->cleanup;
+    $_[0]->close;
 
     return;
 }
@@ -335,7 +335,7 @@ Data::Record::Serialize::Role::Base
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =begin pod_coverage
 
