@@ -2,7 +2,7 @@ package Data::Record::Serialize::Role::Default;
 
 use Moo::Role;
 
-our $VERSION = '0.10'; # TRIAL
+our $VERSION = '0.11'; # TRIAL
 
 use Hash::Util qw[ hv_store ];
 
@@ -88,10 +88,6 @@ before 'send' => sub {
 };
 
 
-# this is overridden by the composing module, but must exist here in
-# case it doesn't exist there.
-sub cleanup { }
-
 1;
 
 =pod
@@ -102,7 +98,7 @@ Data::Record::Serialize::Role::Default
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =begin pod_coverage
 
