@@ -5,7 +5,7 @@ package Data::Record::Serialize::Sink::stream;
 
 use Moo::Role;
 
-our $VERSION = '0.10'; # TRIAL
+our $VERSION = '0.11'; # TRIAL
 
 use IO::File;
 
@@ -37,14 +37,15 @@ has fh => (
 #pod
 #pod =head3 say
 #pod
+#pod =head3 close
+#pod
 #pod =end pod_coverage
 #pod
 #pod =cut
 
 sub print { shift->fh->print( @_ ) }
 sub say   { shift->fh->say( @_ ) }
-
-
+sub close { shift->fh->close }
 
 with 'Data::Record::Serialize::Role::Sink';
 
@@ -58,7 +59,7 @@ Data::Record::Serialize::Sink::stream - output encoded data to a stream.
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -81,6 +82,8 @@ It performs the L<B<Data::Record::Serialize::Role::Sink>> role.
 
 =head3 say
 
+=head3 close
+
 =end pod_coverage
 
 =head1 INTERFACE
